Compact one-screen summary: target, term, effective effect size, estimated per-cell and total sample sizes, and the first and last rows of the power curve.
Usage
# S3 method for class 'anovapowersim_curve'
print(x, ...)Compact one-screen summary: target, term, effective effect size, estimated per-cell and total sample sizes, and the first and last rows of the power curve.
# S3 method for class 'anovapowersim_curve'
print(x, ...)